package com.nemrodsoftware.maven;

/*
 * Copyright 2001-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.File;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;

import com.nemrodsoftware.INemrodClient;
import com.nemrodsoftware.NemrodClient;
import com.nemrodsoftware.action.SyncAction;
import com.nemrodsoftware.config.NemrodConfiguration;

/**
 * Goal which import resource file from a Nemrod instance
 *
 * @goal sync
 * 
 * @phase process-sources
 */
public class SyncMojo
    extends AbstractMojo
{
    /**
     * Resource folder
     * @parameter expression="${sync.workfolder}" default-value="${project.build.outputDirectory}"
     */
    private File workfolder;    
    
    /**
     * Login.
     * @parameter expression="${sync.login}" 
     * @required
     */
    private String login;

    /**
     * Password.
     * @parameter expression="${sync.password}" 
     * @required
     */
    private String password;
    
    /**
     * Url.
     * @parameter expression="${sync.url}"  default-value="http://live.nemrod-software.com"
     * @required
     */
    private String url;  
    
    /**
     * Project name.
     * @parameter expression="${sync.project}"
     * @required
     */
    private String projectName;        

    /**
     * the list of bundle to synchronize
     *
     * @parameter expression="${sync.bundles}"
     * @required
     */
    private List<String> bundleNames;

    /**
     * Sync format
     */
    private static final String FORMAT = "java";        

    public void execute()
        throws MojoExecutionException
    {
        try
        {
            INemrodClient client = new NemrodClient(url, login, password);
            
            NemrodConfiguration conf = new NemrodConfiguration();
            conf.setSyncFormat(FORMAT);
            conf.setLogin(login);
            conf.setPassword(password);
            conf.setProjectName(projectName);
            
            getLog().info("Action : sync ");
            getLog().info("url="+url);
            getLog().info("login="+login);
            getLog().info("project="+projectName);
            
            SyncAction action = new SyncAction(conf, client);

            for (String bundleName : bundleNames)
            {
                if (bundleName.contains("/"))
                {
                    String moduleName = StringUtils.substringAfterLast(bundleName,"/");
                    String modulePath = StringUtils.substringBeforeLast(bundleName,"/");
                    conf.setModule(moduleName);
                    conf.setModulePath(modulePath);
                }
                else
                {
                    conf.setModule(bundleName);
                    conf.setModulePath("");
                }                        
                conf.setMasterFile(new File(workfolder,bundleName+".properties").getAbsolutePath());                
                
                getLog().info("");
                getLog().info("Synchronize default bundle ("+conf.getModule()+ ")...");
                
                action.execute();
            }            
        }
        catch (Exception e)
        {
            throw new MojoExecutionException("Unable to import resource bundles",e);
        }
    }
}
